@@ -4,7 +4,7 @@ def get():
     the new json format expressed as a function
     """
     data = {
-     'usa-alabama': {'0-5': 5.9,
+     'USA-Alabama': {'0-5': 5.9,
       '5-9': 5.9,
       '10-14': 6.6,
       '15-19': 6.8,
@@ -22,7 +22,7 @@ def get():
       '75-79': 3.1,
       '80-84': 2.0,
       '85+': 1.7},
-     'usa-alaska': {'0-5': 7.1,
+     'USA-Alaska': {'0-5': 7.1,
       '5-9': 7.1,
       '10-14': 6.7,
       '15-19': 6.6,
@@ -40,7 +40,7 @@ def get():
       '75-79': 1.7,
       '80-84': 1.1,
       '85+': 1.0},
-     'usa-arizona': {'0-5': 6.1,
+     'USA-Arizona': {'0-5': 6.1,
       '5-9': 6.2,
       '10-14': 6.8,
       '15-19': 6.7,
@@ -58,7 +58,7 @@ def get():
       '75-79': 3.4,
       '80-84': 2.1,
       '85+': 1.9},
-     'usa-arkansas': {'0-5': 6.2,
+     'USA-Arkansas': {'0-5': 6.2,
       '5-9': 6.4,
       '10-14': 6.8,
       '15-19': 6.9,
@@ -76,7 +76,7 @@ def get():
       '75-79': 3.2,
       '80-84': 1.9,
       '85+': 1.9},
-     'usa-california': {'0-5': 6.1,
+     'USA-California': {'0-5': 6.1,
       '5-9': 6.1,
       '10-14': 6.7,
       '15-19': 6.5,
@@ -94,7 +94,7 @@ def get():
       '75-79': 2.5,
       '80-84': 1.7,
       '85+': 1.8},
-     'usa-colorado': {'0-5': 5.9,
+     'USA-Colorado': {'0-5': 5.9,
       '5-9': 6.2,
       '10-14': 6.4,
       '15-19': 6.5,
@@ -112,7 +112,7 @@ def get():
       '75-79': 2.3,
       '80-84': 1.5,
       '85+': 1.5},
-     'usa-connecticut': {'0-5': 5.1,
+     'USA-Connecticut': {'0-5': 5.1,
       '5-9': 5.4,
       '10-14': 6.3,
       '15-19': 6.8,
@@ -130,7 +130,7 @@ def get():
       '75-79': 3.1,
       '80-84': 2.0,
       '85+': 2.5},
-     'usa-delaware': {'0-5': 5.6,
+     'USA-Delaware': {'0-5': 5.6,
       '5-9': 5.4,
       '10-14': 6.5,
       '15-19': 6.1,
@@ -148,7 +148,7 @@ def get():
       '75-79': 3.8,
       '80-84': 1.8,
       '85+': 1.9},
-     'usa-district of columbia': {'0-5': 6.5,
+     'USA-District of Columbia': {'0-5': 6.5,
       '5-9': 4.7,
       '10-14': 4.8,
       '15-19': 5.3,
@@ -166,7 +166,7 @@ def get():
       '75-79': 2.3,
       '80-84': 1.4,
       '85+': 1.6},
-     'usa-florida': {'0-5': 5.3,
+     'USA-Florida': {'0-5': 5.3,
       '5-9': 5.3,
       '10-14': 5.8,
       '15-19': 5.8,
@@ -184,7 +184,7 @@ def get():
       '75-79': 3.9,
       '80-84': 2.6,
       '85+': 2.6},
-     'usa-georgia': {'0-5': 6.1,
+     'USA-Georgia': {'0-5': 6.1,
       '5-9': 6.5,
       '10-14': 7.0,
       '15-19': 7.2,
@@ -202,7 +202,7 @@ def get():
       '75-79': 2.5,
       '80-84': 1.5,
       '85+': 1.4},
-     'usa-hawaii': {'0-5': 6.2,
+     'USA-Hawaii': {'0-5': 6.2,
       '5-9': 5.9,
       '10-14': 6.0,
       '15-19': 5.5,
@@ -220,7 +220,7 @@ def get():
       '75-79': 2.9,
       '80-84': 2.2,
       '85+': 2.8},
-     'usa-idaho': {'0-5': 6.5,
+     'USA-Idaho': {'0-5': 6.5,
       '5-9': 7.1,
       '10-14': 7.4,
       '15-19': 7.2,
@@ -238,7 +238,7 @@ def get():
       '75-79': 3.0,
       '80-84': 1.6,
       '85+': 1.7},
-     'usa-illinois': {'0-5': 6.0,
+     'USA-Illinois': {'0-5': 6.0,
       '5-9': 6.0,
       '10-14': 6.6,
       '15-19': 6.6,
@@ -256,7 +256,7 @@ def get():
       '75-79': 2.8,
       '80-84': 1.8,
       '85+': 2.0},
-     'usa-indiana': {'0-5': 6.2,
+     'USA-Indiana': {'0-5': 6.2,
       '5-9': 6.4,
       '10-14': 6.7,
       '15-19': 6.9,
@@ -274,7 +274,7 @@ def get():
       '75-79': 2.8,
       '80-84': 1.8,
       '85+': 1.9},
-     'usa-iowa': {'0-5': 6.3,
+     'USA-Iowa': {'0-5': 6.3,
       '5-9': 6.3,
       '10-14': 6.8,
       '15-19': 7.0,
@@ -292,7 +292,7 @@ def get():
       '75-79': 3.0,
       '80-84': 2.2,
       '85+': 2.4},
-     'usa-kansas': {'0-5': 6.4,
+     'USA-Kansas': {'0-5': 6.4,
       '5-9': 6.5,
       '10-14': 7.2,
       '15-19': 7.0,
@@ -310,7 +310,7 @@ def get():
       '75-79': 2.7,
       '80-84': 1.9,
       '85+': 2.2},
-     'usa-kentucky': {'0-5': 6.1,
+     'USA-Kentucky': {'0-5': 6.1,
       '5-9': 6.3,
       '10-14': 6.4,
       '15-19': 6.5,
@@ -328,7 +328,7 @@ def get():
       '75-79': 2.9,
       '80-84': 2.0,
       '85+': 1.8},
-     'usa-louisiana': {'0-5': 6.5,
+     'USA-Louisiana': {'0-5': 6.5,
       '5-9': 6.4,
       '10-14': 6.8,
       '15-19': 6.6,
@@ -346,7 +346,7 @@ def get():
       '75-79': 2.8,
       '80-84': 1.8,
       '85+': 1.6},
-     'usa-maine': {'0-5': 4.7,
+     'USA-Maine': {'0-5': 4.7,
       '5-9': 5.1,
       '10-14': 5.4,
       '15-19': 5.8,
@@ -364,7 +364,7 @@ def get():
       '75-79': 3.4,
       '80-84': 2.3,
       '85+': 2.6},
-     'usa-maryland': {'0-5': 6.0,
+     'USA-Maryland': {'0-5': 6.0,
       '5-9': 6.0,
       '10-14': 6.4,
       '15-19': 6.3,
@@ -382,7 +382,7 @@ def get():
       '75-79': 2.8,
       '80-84': 1.8,
       '85+': 1.8},
-     'usa-massachusetts': {'0-5': 5.2,
+     'USA-Massachusetts': {'0-5': 5.2,
       '5-9': 5.4,
       '10-14': 5.7,
       '15-19': 6.6,
@@ -400,7 +400,7 @@ def get():
       '75-79': 2.8,
       '80-84': 1.9,
       '85+': 2.2},
-     'usa-michigan': {'0-5': 5.7,
+     'USA-Michigan': {'0-5': 5.7,
       '5-9': 5.9,
       '10-14': 6.2,
       '15-19': 6.6,
@@ -418,7 +418,7 @@ def get():
       '75-79': 3.1,
       '80-84': 2.0,
       '85+': 2.0},
-     'usa-minnesota': {'0-5': 6.3,
+     'USA-Minnesota': {'0-5': 6.3,
       '5-9': 6.4,
       '10-14': 6.6,
       '15-19': 6.4,
@@ -436,7 +436,7 @@ def get():
       '75-79': 2.8,
       '80-84': 1.9,
       '85+': 2.1},
-     'usa-mississippi': {'0-5': 6.0,
+     'USA-Mississippi': {'0-5': 6.0,
       '5-9': 6.4,
       '10-14': 7.2,
       '15-19': 7.3,
@@ -454,7 +454,7 @@ def get():
       '75-79': 3.0,
       '80-84': 1.8,
       '85+': 1.6},
-     'usa-missouri': {'0-5': 6.0,
+     'USA-Missouri': {'0-5': 6.0,
       '5-9': 6.1,
       '10-14': 6.5,
       '15-19': 6.4,
@@ -472,7 +472,7 @@ def get():
       '75-79': 3.1,
       '80-84': 2.0,
       '85+': 2.0},
-     'usa-montana': {'0-5': 5.8,
+     'USA-Montana': {'0-5': 5.8,
       '5-9': 5.8,
       '10-14': 6.4,
       '15-19': 6.3,
@@ -490,7 +490,7 @@ def get():
       '75-79': 3.5,
       '80-84': 2.0,
       '85+': 2.0},
-     'usa-nebraska': {'0-5': 6.8,
+     'USA-Nebraska': {'0-5': 6.8,
       '5-9': 6.7,
       '10-14': 7.1,
       '15-19': 6.9,
@@ -508,7 +508,7 @@ def get():
       '75-79': 2.6,
       '80-84': 2.0,
       '85+': 2.2},
-     'usa-nevada': {'0-5': 6.1,
+     'USA-Nevada': {'0-5': 6.1,
       '5-9': 6.2,
       '10-14': 6.6,
       '15-19': 6.0,
@@ -526,7 +526,7 @@ def get():
       '75-79': 2.8,
       '80-84': 1.7,
       '85+': 1.5},
-     'usa-new hampshire': {'0-5': 4.6,
+     'USA-New Hampshire': {'0-5': 4.6,
       '5-9': 5.1,
       '10-14': 5.7,
       '15-19': 6.8,
@@ -544,7 +544,7 @@ def get():
       '75-79': 3.1,
       '80-84': 1.9,
       '85+': 2.3},
-     'usa-new jersey': {'0-5': 5.8,
+     'USA-New Jersey': {'0-5': 5.8,
       '5-9': 5.8,
       '10-14': 6.4,
       '15-19': 6.2,
@@ -562,7 +562,7 @@ def get():
       '75-79': 2.9,
       '80-84': 1.9,
       '85+': 2.2},
-     'usa-new mexico': {'0-5': 5.7,
+     'USA-New Mexico': {'0-5': 5.7,
       '5-9': 6.1,
       '10-14': 7.2,
       '15-19': 6.8,
@@ -580,7 +580,7 @@ def get():
       '75-79': 3.1,
       '80-84': 2.0,
       '85+': 1.9},
-     'usa-new york': {'0-5': 5.8,
+     'USA-New York': {'0-5': 5.8,
       '5-9': 5.5,
       '10-14': 5.9,
       '15-19': 6.2,
@@ -598,7 +598,7 @@ def get():
       '75-79': 2.9,
       '80-84': 2.0,
       '85+': 2.2},
-     'usa-north carolina': {'0-5': 5.8,
+     'USA-North Carolina': {'0-5': 5.8,
       '5-9': 6.0,
       '10-14': 6.5,
       '15-19': 6.8,
@@ -616,7 +616,7 @@ def get():
       '75-79': 3.0,
       '80-84': 1.8,
       '85+': 1.7},
-     'usa-north dakota': {'0-5': 6.9,
+     'USA-North Dakota': {'0-5': 6.9,
       '5-9': 6.7,
       '10-14': 6.2,
       '15-19': 6.1,
@@ -634,7 +634,7 @@ def get():
       '75-79': 2.5,
       '80-84': 2.0,
       '85+': 2.4},
-     'usa-ohio': {'0-5': 5.9,
+     'USA-Ohio': {'0-5': 5.9,
       '5-9': 5.9,
       '10-14': 6.4,
       '15-19': 6.6,
@@ -652,7 +652,7 @@ def get():
       '75-79': 3.1,
       '80-84': 2.0,
       '85+': 2.1},
-     'usa-oklahoma': {'0-5': 6.5,
+     'USA-Oklahoma': {'0-5': 6.5,
       '5-9': 6.6,
       '10-14': 7.1,
       '15-19': 6.9,
@@ -670,7 +670,7 @@ def get():
       '75-79': 2.8,
       '80-84': 1.9,
       '85+': 1.8},
-     'usa-oregon': {'0-5': 5.5,
+     'USA-Oregon': {'0-5': 5.5,
       '5-9': 5.7,
       '10-14': 6.1,
       '15-19': 6.0,
@@ -688,7 +688,7 @@ def get():
       '75-79': 3.1,
       '80-84': 2.0,
       '85+': 1.9},
-     'usa-pennsylvania': {'0-5': 5.5,
+     'USA-Pennsylvania': {'0-5': 5.5,
       '5-9': 5.5,
       '10-14': 6.1,
       '15-19': 6.4,
@@ -706,7 +706,7 @@ def get():
       '75-79': 3.3,
       '80-84': 2.3,
       '85+': 2.4},
-     'usa-puerto rico': {'0-5': 3.9,
+     'USA-Puerto Rico': {'0-5': 3.9,
       '5-9': 5.2,
       '10-14': 5.7,
       '15-19': 6.6,
@@ -724,7 +724,7 @@ def get():
       '75-79': 4.0,
       '80-84': 2.8,
       '85+': 2.6},
-     'usa-rhode island': {'0-5': 5.1,
+     'USA-Rhode Island': {'0-5': 5.1,
       '5-9': 5.4,
       '10-14': 5.2,
       '15-19': 7.1,
@@ -742,7 +742,7 @@ def get():
       '75-79': 2.9,
       '80-84': 2.1,
       '85+': 2.5},
-     'usa-south carolina': {'0-5': 5.7,
+     'USA-South Carolina': {'0-5': 5.7,
       '5-9': 6.0,
       '10-14': 6.4,
       '15-19': 6.7,
@@ -760,7 +760,7 @@ def get():
       '75-79': 3.2,
       '80-84': 1.9,
       '85+': 1.7},
-     'usa-south dakota': {'0-5': 6.8,
+     'USA-South Dakota': {'0-5': 6.8,
       '5-9': 6.7,
       '10-14': 7.0,
       '15-19': 6.8,
@@ -778,7 +778,7 @@ def get():
       '75-79': 2.7,
       '80-84': 1.8,
       '85+': 2.5},
-     'usa-tennessee': {'0-5': 6.0,
+     'USA-Tennessee': {'0-5': 6.0,
       '5-9': 6.1,
       '10-14': 6.4,
       '15-19': 6.5,
@@ -796,7 +796,7 @@ def get():
       '75-79': 3.0,
       '80-84': 1.9,
       '85+': 1.7},
-     'usa-texas': {'0-5': 7.0,
+     'USA-Texas': {'0-5': 7.0,
       '5-9': 6.9,
       '10-14': 7.6,
       '15-19': 7.2,
@@ -814,7 +814,7 @@ def get():
       '75-79': 2.2,
       '80-84': 1.4,
       '85+': 1.3},
-     'usa-utah': {'0-5': 7.9,
+     'USA-Utah': {'0-5': 7.9,
       '5-9': 8.1,
       '10-14': 8.6,
       '15-19': 7.9,
@@ -832,7 +832,7 @@ def get():
       '75-79': 1.9,
       '80-84': 1.4,
       '85+': 1.1},
-     'usa-vermont': {'0-5': 4.6,
+     'USA-Vermont': {'0-5': 4.6,
       '5-9': 5.1,
       '10-14': 5.4,
       '15-19': 6.7,
@@ -850,7 +850,7 @@ def get():
       '75-79': 3.5,
       '80-84': 2.1,
       '85+': 2.1},
-     'usa-virginia': {'0-5': 5.9,
+     'USA-Virginia': {'0-5': 5.9,
       '5-9': 6.0,
       '10-14': 6.3,
       '15-19': 6.6,
@@ -868,7 +868,7 @@ def get():
       '75-79': 2.8,
       '80-84': 1.8,
       '85+': 1.7},
-     'usa-washington': {'0-5': 6.1,
+     'USA-Washington': {'0-5': 6.1,
       '5-9': 6.2,
       '10-14': 6.2,
       '15-19': 6.0,
@@ -886,7 +886,7 @@ def get():
       '75-79': 2.7,
       '80-84': 1.6,
       '85+': 1.7},
-     'usa-west virginia': {'0-5': 5.2,
+     'USA-West Virginia': {'0-5': 5.2,
       '5-9': 5.4,
       '10-14': 5.9,
       '15-19': 6.2,
@@ -904,7 +904,7 @@ def get():
       '75-79': 3.6,
       '80-84': 2.3,
       '85+': 2.2},
-     'usa-wisconsin': {'0-5': 5.7,
+     'USA-Wisconsin': {'0-5': 5.7,
       '5-9': 5.9,
       '10-14': 6.4,
       '15-19': 6.5,
@@ -922,7 +922,7 @@ def get():
       '75-79': 2.9,
       '80-84': 2.1,
       '85+': 2.1},
-     'usa-wyoming': {'0-5': 6.1,
+     'USA-Wyoming': {'0-5': 6.1,
       '5-9': 6.0,
       '10-14': 7.0,
       '15-19': 7.1,
