@@ -33,7 +33,7 @@ def handle_args(fig_args=None, plot_args=None, scatter_args=None, axis_args=None
     return args
 
 
-def handle_to_plot(which, to_plot, n_cols):
+def handle_to_plot(which, to_plot, n_cols, sim):
     ''' Handle which quantities to plot '''
 
     if to_plot is None:
@@ -44,6 +44,12 @@ def handle_to_plot(which, to_plot, n_cols):
         else:
             errormsg = f'"which" must be "sim" or "scens", not "{which}"'
             raise NotImplementedError(errormsg)
+    elif isinstance(to_plot, list): # If a list of keys has been supplied
+        to_plot_list = to_plot # Store separately
+        to_plot = sc.odict() # Create the dict
+        for reskey in to_plot_list:
+            to_plot[sim.results[reskey].name] = [reskey] # Use the result name as the key and the reskey as the value
+
     to_plot = sc.odict(sc.dcp(to_plot)) # In case it's supplied as a dict
 
     n_rows = np.ceil(len(to_plot)/n_cols) # Number of subplot rows to have
@@ -206,7 +212,7 @@ def plot_sim(sim, to_plot=None, do_save=None, fig_path=None, fig_args=None, plot
 
     # Handle inputs
     args = handle_args(fig_args, plot_args, scatter_args, axis_args, fill_args, legend_args)
-    to_plot, n_rows = handle_to_plot('sim', to_plot, n_cols)
+    to_plot, n_rows = handle_to_plot('sim', to_plot, n_cols, sim=sim)
     fig, figs, ax = create_figs(args, font_size, font_family, sep_figs, fig)
 
     # Do the plotting
@@ -242,13 +248,14 @@ def plot_scens(scens, to_plot=None, do_save=None, fig_path=None, fig_args=None,
 
     # Handle inputs
     args = handle_args(fig_args, plot_args, scatter_args, axis_args, fill_args, legend_args)
-    to_plot, n_rows = handle_to_plot('scens', to_plot, n_cols)
+    to_plot, n_rows = handle_to_plot('scens', to_plot, n_cols, sim=scens.base_sim)
     fig, figs, ax = create_figs(args, font_size, font_family, sep_figs, fig)
 
     # Do the plotting
     default_colors = sc.gridcolors(ncolors=len(scens.sims))
     for pnum,title,reskeys in to_plot.enumitems():
         ax = create_subplots(figs, fig, ax, n_rows, n_cols, pnum, args.fig, sep_figs, log_scale, title)
+        reskeys = sc.promotetolist(reskeys) # In case it's a string
         for reskey in reskeys:
             resdata = scens.results[reskey]
             for snum,scenkey,scendata in resdata.enumitems():
@@ -581,6 +588,18 @@ def get_individual_states(sim):
 # Default settings for the Plotly legend
 plotly_legend = dict(legend_orientation="h", legend=dict(x=0.0, y=1.18))
 
+
+def plotly_interventions(sim, fig):
+    ''' Add vertical lines for interventions to the plot '''
+    if sim['interventions']:
+        for interv in sim['interventions']:
+            if hasattr(interv, 'days'):
+                for interv_day in interv.days:
+                    if interv_day and interv_day < sim['n_days']:
+                        fig.add_shape(dict(type="line", xref="x", yref="paper", x0=interv_day, x1=interv_day, y0=0, y1=1, name='Intervention', line=dict(width=0.5, dash='dash')))
+                        fig.update_layout(annotations=[dict(x=interv_day, y=1.07, xref="x", yref="paper", text="Intervention change", showarrow=False)])
+    return
+
 def plotly_sim(sim):
     ''' Main simulation results -- parallel of sim.plot() '''
 
@@ -599,14 +618,7 @@ def plotly_sim(sim):
                 ydata = sim.data[key]
                 fig.add_trace(go.Scatter(x=xdata, y=ydata, mode='markers', name=label + ' (data)', line_color=this_color))
 
-        if sim['interventions']:
-            for interv in sim['interventions']:
-                if hasattr(interv, 'days'):
-                    for interv_day in interv.days:
-                        if interv_day > 0 and interv_day < sim['n_days']:
-                            fig.add_shape(dict(type="line", xref="x", yref="paper", x0=interv_day, x1=interv_day, y0=0, y1=1, name='Intervention', line=dict(width=0.5, dash='dash')))
-                            fig.update_layout(annotations=[dict(x=interv_day, y=1.07, xref="x", yref="paper", text="Intervention change", showarrow=False)])
-
+        plotly_interventions(sim, fig)
         fig.update_layout(title={'text':title}, yaxis_title='Count', autosize=True, **plotly_legend)
 
         plots.append(fig)
@@ -631,15 +643,7 @@ def plotly_people(sim, do_show=False):
             name=state['name']
         ))
 
-    if sim['interventions']:
-        for interv in sim['interventions']:
-                if hasattr(interv, 'days'):
-                    if interv.do_plot:
-                        for interv_day in interv.days:
-                            if interv_day > 0 and interv_day < sim['n_days']:
-                                fig.add_shape(dict(type="line", xref="x", yref="paper", x0=interv_day, x1=interv_day, y0=0, y1=1, name='Intervention', line=dict(width=0.5, dash='dash')))
-                                fig.update_layout(annotations=[dict(x=interv_day, y=1.07, xref="x", yref="paper", text="Intervention change", showarrow=False)])
-
+    plotly_interventions(sim, fig)
     fig.update_layout(yaxis_range=(0, sim.n))
     fig.update_layout(title={'text': 'Numbers of people by health state'}, yaxis_title='People', autosize=True, **plotly_legend)
 
